@@ -12,7 +12,7 @@ use B ();
 
 use Class::C3;
 
-$JavaScript::Dumper::VERSION = '0.01';
+$JavaScript::Dumper::VERSION = '0.011';
 
 @JavaScript::Dumper::EXPORT = qw(js_dumper);
 
@@ -32,7 +32,7 @@ sub value_to_json {
 		return "false" if($$value eq "0");
 		return $$value;
 	} elsif(!$type && $value =~ /^\d+$/ ) {
-		return $value if(eval($value) eq $value);
+		return $value if( int($value) eq $value);
 	}
 	$self->next::method($value);
 }
